@@ -1,9 +1,10 @@
 import enum
 from pathlib import Path
-from typing import Any, Optional
+from typing import Any
 from typing import Callable
 from typing import Dict
 from typing import List
+from typing import Optional
 from typing import Set
 from typing import Tuple
 
